@@ -98,9 +98,9 @@ def prop_or(default, key, dct_or_obj):
     elif isinstance(dict, dct_or_obj):
         value = dct_or_obj[key] if has(key, dct_or_obj) else default
     elif isinstance(list, dct_or_obj) or isinstance(tuple, dct_or_obj):
-        value = dct_or_obj[key] if length(dct_or_obj) > key and dct_or_obj[key] else default
+        value = dct_or_obj[key] if length(dct_or_obj) > key and dct_or_obj[key] is not None else default
     elif isinstance(object, dct_or_obj):
-        value = getattr(key, dct_or_obj) if hasattr(dct_or_obj, key) and getattr(key, dct_or_obj) else default
+        value = getattr(key, dct_or_obj) if hasattr(dct_or_obj, key) and getattr(key, dct_or_obj) is not None else default
     else:
         value = default
     # 0 and False are ok, None defaults
@@ -1237,6 +1237,7 @@ def group_by(f, list):
 
     return index_by_and_map_items(f, lambda item: item, list)
 
+
 def index_by(f, list):
     """
     Ramda implementation of index_by. Makes the result of f the key of a dict. Duplicates are overwritten
